<?php

/// \file converter.php Contains the Converter base class.

/// Converts JSON data to proper HTML response
/**
 * Converter is an abstract base class that represents a conversion for a particular type of item returned by the API.
 */
abstract class Converter
{
    /// Performs the actual conversion
    /**
     * The data returned by this function is an array of objects that contain the following members:
     * - title
     * - description
     * - link
     * - date
     * \param[in] $json_array the JSON array contained in the API response
     * \return an array that contains the HTML for the items
     */
    public function PerformConversion($json_array)
    {
        // Contains the array of HTML items
        $output = array();
        
        foreach($json_array as $item)
        {
            $output[] = array('title'       => $this->GetTitle($item),
                              'description' => $this->GetDescription($item),
                              'link'        => $this->GetLink($item),
                              'date'        => $this->GetDate($item));
        }
        
        return $output;
    }
    
    /// Returns the title of the given item
    /**
     * \param[in] $json_item the JSON for the particular item
     * \return the HTML for the title of the item
     */
    abstract protected function GetTitle($json_item);
    
    /// Returns the description of the given item
    /**
     * \param[in] $json_item the JSON for the particular item
     * \return the HTML for the description of the item
     */
    abstract protected function GetDescription($json_item);
    
    /// Returns the link for the given item
    /**
     * \param[in] $json_item the JSON for the particular item
     * \return the link for the item
     */
    abstract protected function GetLink($json_item);
    
    /// Returns the date of the given item
    /**
     * \param[in] $json_item the JSON for the particular item
     * \return the date of the item
     */
    abstract protected function GetDate($json_item);
}

?>
