<?php

/// \file item_converter.php Contains the conversion class for item objects.

// This class derives from Converter
require_once 'converter.php';

/// Provides conversion for item objects
/**
 * <i>Note: unfortunately, the API uses 'item' for two different objects returned: <kbd>/sites</kbd> and <kbd>/users/{ID}/associated</kbd>.</i>
 *
 * Because of this, this class is slightly more complicated than it needs to be.
 */
class ItemConverter extends Converter
{
    /// Determines if this item is a site or associated user
    /**
     * \param[in] $json_item the JSON data for the item
     * \return TRUE or FALSE depending on whether this item represents a site or not
     */
    private function IsSite($json_item)
    {
        return isset($json_item['main_site']);
    }
    
    protected function GetTitle($json_item)
    {
        if($this->IsSite($json_item))
            return $json_item['main_site']['name'];
        else
            return $json_item['site_name'];
    }
    
    protected function GetDescription($json_item)
    {
        if($this->IsSite($json_item))
            return $json_item['main_site']['description'];
        else
            return '<i>No data.</i>';
    }
    
    protected function GetLink($json_item)
    {
        if($this->IsSite($json_item))
            return "http://{$json_item['main_site']['site_url']}/";
        else
            return "http://stackexchange.com/users/{$json_item['association_id']}?tab=accounts";
    }
    
    protected function GetDate($json_item)
    {
        if($this->IsSite($json_item))
            return date(DATE_RSS, $json_item['creation_date']);
        else
            return date(DATE_RSS, $json_item['user_creation_date']);
    }
}

?>
