<?php

/// \file post_timeline_converter.php Contains the conversion class for post timeline objects.

// This class derives from Converter
require_once 'converter.php';

/// Provides conversion for post timeline objects
/**
 * An entry in the timeline can consist of the following types:
 * - <kbd>question</kbd>
 * - <kbd>answer</kbd>
 * - <kbd>comment</kbd>
 * - <kbd>revision</kbd>
 * - <kbd>votes</kbd>
 * - <kbd>state</kbd>
 * - <kbd>accepted</kbd>
 * - <kbd>unaccepted</kbd>
 */
class PostTimelineConverter extends Converter
{
    protected function GetTitle($json_item)
    {
        // Determine whether this action affects a question or answer
        $l_affects = ($json_item['question_id'] == $json_item['post_id'])?'question':'answer';
        $u_affects = ucwords($l_affects);
        
        switch($json_item['timeline_type'])
        {
            case 'question':   $event_desc = "Question asked by {$json_item['owner']['display_name']}."; break;
            case 'answer':     $event_desc = "Question answered by {$json_item['owner']['display_name']}."; break;
            case 'comment':    $event_desc = "{$json_item['owner']['display_name']}'s {$l_affects} commented on."; break;
            case 'revision':   $event_desc = "{$json_item['owner']['display_name']}'s {$l_affects} edited by {$json_item['user']['display_name']}."; break;
            case 'votes':      $event_desc = "{$u_affects} voted on."; break;
            case 'state':      $event_desc = "{$u_affects}'s state changed."; break;
            case 'accepted':   $event_desc = "{$json_item['owner']['display_name']}'s {$l_affects} accepted."; break;
            case 'unaccepted': $event_desc = "{$json_item['owner']['display_name']}'s {$l_affects} unaccepted."; break;
            default:           $event_desc = "[Unknown]"; break;
        }
        
        return $event_desc;
    }
    
    protected function GetDescription($json_item)
    {
        return '<i>No data.</i>';
    }
    
    protected function GetLink($json_item)
    {
        return "http://{$_GET['site']}/posts/{$json_item['post_id']}/revisions";
    }
    
    protected function GetDate($json_item)
    {
        return date(DATE_RSS, $json_item['creation_date']);
    }
}

?>
