<?php

/// \file user_timeline_converter.php Contains the conversion class for user timeline objects.

// This class derives from Converter
require_once 'converter.php';

/// Provides conversion for user timeline objects
class UserTimelineConverter extends Converter
{
    protected function GetTitle($json_item)
    {
        switch($json_item['timeline_type'])
        {
            case 'askoranswered':
                if($json_item['post_type'] == 'question')
                    return "Asked question \"{$json_item['description']}\"";
                else
                    return "Answered question \"{$json_item['description']}\"";
            case 'accepted':
                return "Accepted answer to \"{$json_item['description']}\"";
            case 'badge':
                return "Awarded {$json_item['description']} badge.";
            case 'comment':
                if($json_item['post_type'] == 'question')
                    return "Commented on question \"{$json_item['description']}\"";
                else
                    return "Commented on answer to \"{$json_item['description']}\"";
            case 'revision':
                return "Made revision to \"{$json_item['description']}\"";
            default:
                return '[Unknown]';
        }
    }
    
    protected function GetDescription($json_item)
    {
        return ($json_item['timeline_type'] == 'askoranswered')?'<i>No data.</i>':$json_item['detail'];
    }
    
    protected function GetLink($json_item)
    {
        switch($json_item['timeline_type'])
        {
            case 'badge':         return "http://{$_GET['site']}/users/{$json_item['user_id']}";
            case 'askoranswered':
            case 'accepted':
            case 'comment':       return "http://{$_GET['site']}/questions/{$json_item['post_id']}";
            case 'revision':      return "http://{$_GET['site']}/posts/{$json_item['post_id']}/revisions";
            default:              return '[Unknown]';
        }
    }
    
    protected function GetDate($json_item)
    {
        return date(DATE_RSS, $json_item['creation_date']);
    }
}

?>
